#########################################################################################
############################  PROBABILITY DISTRIBUTIONS  ################################
#########################################################################################

#########################################################################################
############################  BINOMIAL DISTRIBUTION  ####################################
#########################################################################################

#Set parameters
n <- 25
k <- 10
p <- 0.5

#Four probability functions:
#Probability Density Function (PDF)
dbinom(x = k, size = n, prob = p)

#Cumulative Distribution Function (CDF)
pbinom(q = k, size = n, prob = p)

#Quantiles
#qbinom(p = k, size = n, prob = p, lower.tail = TRUE, log.p = FALSE)

#Random variable generator
set.seed(1)
rbinom(n = 1, size = n, prob = p)

#Create probability density function and plot
n <- 25
k <- seq(0, n, by = 1)
p <- 0.5
x <- dbinom(k, size=n, p=p)
barplot(x, names = k)

#Create cumulative distribution function and plot
x <- pbinom(k, size=n, p=p)
barplot(x, names = k)

#What if we change the number of flips (n)?
n <- 200
k <- seq(0, n, by = 1)
x <- dbinom(k, size=n, p=p)
barplot(x, names = k)

#What if we change the probability of success (p)? 
n <- 25
k <- seq(0, n, by = 1)
p <- 0.8
x <- dbinom(k, size=n, p=p)
barplot(x, names = k)


n <- 53
x <- 21
p <- 0.2
pbinom(x, size=n, p=p, lower.tail = FALSE)


#########################################################################################
############################  POISSON DISTRIBUTION   ####################################
#########################################################################################

#Run pdf
dpois(2, lambda = 0.5)
dpois(2, lambda = 0.1)
dpois(2, lambda = 4.2)

#What about 2 or less?
ppois(2, lambda = 0.5)
ppois(2, lambda = 0.1)
ppois(2, lambda = 4.2)

#What about 2 or more?
ppois(2, lambda = 0.5, lower.tail = FALSE)
ppois(2, lambda = 0.1, lower.tail = FALSE)
ppois(2, lambda = 4.2, lower.tail = FALSE)

#Plot pdf
n <- 50
k <- seq(0, n, by = 1)
lambda <- 0.5
x <- dpois(k, lambda = lambda)
barplot(x, names = k)

#What if we change lambda?
n <- 50
k <- seq(0, n, by = 1)
lambda <- 25
x <- dpois(k, lambda = lambda)
barplot(x, names = k)

#What happens when lambda increases? What does the pdf begin to look like?


ppois(2, lambda = 4, lower.tail = FALSE)
1 - ppois(2, lambda = 4, lower.tail = FALSE)


prob.3 <- ppois(3, lambda = 2, lower.tail = FALSE)
prob.5 <- ppois(5, lambda = 2, lower.tail = FALSE)
prob.3 - prob.5

ppois(5, lambda = 2) - ppois(3, lambda = 2)


prob.3 <- ppois(3, lambda = 4.6, lower.tail = TRUE)
prob.1 <- ppois(1, lambda = 4.6, lower.tail = TRUE)
prob.3 - prob.1

ppois(1, lambda = 4.6, lower.tail = FALSE) - ppois(3, lambda = 4.6, lower.tail = FALSE)


#Uniform
?runif

runif(50, min = 1, max = 100)
runif(10, min = 50, max = 75)

#########################################################################################
############################  UNIFORM DISTRIBUTION   #####################################
#########################################################################################

#Use the random number function
runif(10, min=50, max=75) 

#Why should we use the uniform distribution rather than another distribution?


#########################################################################################
############################  NORMAL DISTRIBUTION   #####################################
#########################################################################################

#Assign mean, stdev
mu <- 72
sd <- 15.2

#Cumulative probability that X <= 84
pnorm(84, mean = mu, sd = sd)

#Cumulative probability that X >= 84
pnorm(84, mean = mu, sd = sd, lower.tail = FALSE)

#Plot a normal distribution
k <- seq(0,150,1)
plot(dnorm(k, mean = mu, sd = sd), type = "l")

#Create a vector of random data points from these data
rand.x <- rnorm(5000, mean = mu, sd = sd)
mean(rand.x)
sd(rand.x)
hist(rand.x)

#Lightbulb example
dnorm(250, mean = 300, sd = 50)


#Center and scale and plot - how is this different?
rand.sn <- scale(rand.x, center = TRUE, scale = TRUE)
mean(rand.sn)
sd(rand.sn)
hist(rand.sn)

#########################################################################################
############################  EXPONENTIAL DISTRIBUTION   ################################
#########################################################################################

#Plot distirbution
rate = 1/2
dexp(3, rate = rate)
pexp(3, rate = rate, lower.tail = TRUE)
pexp(3, rate = rate, lower.tail = FALSE)


#Define rate (average)
rate <- 1/3

#Probability x < 2
pexp(2, rate = rate, lower.tail = TRUE)
pexp(2, rate = rate, lower.tail = FALSE)

dexp(2, rate = rate)

#What about if the rate changes?
rate <- 1.5
pexp(2, rate = rate)

#Plot distribution
x <-seq(0,100,1)
plot(dexp(x, rate = 1/3), type = "l", ylim = c(0,1))
curve(dexp(x, rate = 1.5), col = "red", add = TRUE)

plot(pexp(x, rate = 1/3), type = "l")


dexp(10, rate = 1/15)
x <- seq(0,100,1)
plot(dexp(x, rate = 1/15), type = "l")

ppois(300000, lambda = 353000, lower.tail=FALSE)

punif(15, min = 0, max = 40, lower.tail = TRUE)

dnorm(100, mean = 90, sd = 10)

#########################################################################################
############################    CONFIDENCE INTERVALS     ################################
#########################################################################################

