#######################################################################
#######################################################################
########## This sample R code can serve as a resource for    ########## 
########## Hawassa University students and faculty who       ########## 
########## are participating in the workshop offered by      ########## 
########## Dr. Catherine Haase of Montana State University   ########## 
########## as part of a partnership between the Unversity    ########## 
########## of Florida livestock lab and USAID's              ########## 
########## Feed the Future Program                           ##########
#######################################################################
#######################################################################

############################################################################
########################  R BASICS  ########################################
############################################################################

###########################################
#R Syntax
###########################################

#Use "hashtag" to denote comments; these will NOT run
#Great to annotate your code <- VERY IMPORTANT!!!!!!!
#Don't let future you curse past you! 
#Great to block out lines you do not want to run

#R works like a calculator 
1 + 2

#R also works by assigning objects values or characters
#you can use "=" or "<-" to assign objects
#I like using "<-" because "=" is used in other functions
a <- 1
a

b <- 2
b

a + b

c <- a + b
c

###########################################
#R Object Types
###########################################

#Everything in R is an object:

#Logical: ?TRUE?, ?FALSE?
x <- "TRUE"
x

# Integer: 1, 2, 3
a <- 1
a

#Numeric: 2, 2.0, 3.141592
pi

#Complex: 1 + 4i
complex <- 1 + 4i
complex

#Character: ?a?, ?name?
name <- "Catherine"
name


#There are also different types of data structures: 

#Vectors: most common
x <- c(1,2,5.3,6,-2,4) # numeric vector
x

y <- c("one","two","three") # character vector
y

z <- c(TRUE,TRUE,TRUE,FALSE,TRUE,FALSE) #logical vector
z


#Matrices: all columns in a matrix must have the same 
#mode(numeric, character, etc.) and the same length. 
#The general format is

#mymatrix <- matrix(vector, nrow=3, ncol=3, byrow=FALSE, 
#  	     dimnames=list(char_vector_rownames, char_vector_colnames))

#Generates 5 x 4 numeric matrix: 
y <- matrix(1:20, nrow=5,ncol=4)
y

#Another example
cells <- c(1,26,24,68)
rnames <- c("R1", "R2")
cnames <- c("C1", "C2") 
mymatrix <- matrix(cells, nrow=2, ncol=2, byrow=TRUE,
                   dimnames=list(rnames, cnames))


#Dataframe: A data frame is more general than a matrix, 
#in that different columns can have different modes 
#(numeric, character, factor, etc.). 

d <- c(1,2,3,4)
e <- c("red", "white", "red", NA)
f <- c(TRUE,TRUE,TRUE,FALSE)
mydata <- data.frame(d,e,f)
names(mydata) <- c("ID","Color","Passed") # variable names


#Lists: An ordered collection of objects (components). 
#A list allows you to gather a variety of (possibly unrelated) objects under one name.

#example of a list with 4 components - a string, a numeric vector, a matrix, and a scaler 
w <- list(name="Fred", mynumbers=a, mymatrix=y, age=5.3)
w


#Factors
#variable gender with 20 "male" entries and 
#30 "female" entries 
gender <- c(rep("male",20), rep("female", 30)) 
gender <- factor(gender) 

#stores gender as 20 1s and 30 2s and associates
#1=female, 2=male internally (alphabetically)
#R now treats gender as a nominal variable 
summary(gender)


###########################################
#IMPORTING AND EXPORTING DATA IN R
###########################################

#Set working directory manually
setwd("C:\\Users\\Katie Haase\\Desktop\\Workshop")  #the path will change for your work

#Set working directory with RStudio
#>Tools>Set working directory>Choose directory

#Import text files
data <-read.table("bird_data.txt",header=TRUE)

#Lets you choose file from within working directory
#data <-read.table(file.choose(),header=TRUE)

#Import CSV files
data.csv<-read.csv("data.csv",header=T)

#Play with data set
data
head(data)
dim(data)
names(data)
attach(data)
data$SurveyID
class(data$SurveyID)

#Create vector
surveyID <- data$SurveyID
surveyID

###########################################
#SUMMARIZING DATA
###########################################
#Some common functions summarizing data
sum(data$Presence)
?sum
??sum

median(data$Presence)

mean(data$Presence)

sum(data$Presence)/length(data$Presence)

sd(data$Presence)

max(data$Presence)

min(data$Presence)

length(data$Presence)

quantile(data$Presence, prob=0.95)

#This function calculates common summary statistics for each column 
#great for outliers or missing values (N/As)
summary(data)

#tapply: useful when you need to summarize data based on groups or treatments
#tapply(X=summary variable, INDEX=grouping variable, FUN=function)

#Calculate mean of elevation when water is present/not present
tapply(X = data$Elevation, INDEX = data$Water, FUN = mean)
tapply(data$Elevation, data$Water, mean)


###########################################
#MISSING VALUES
###########################################

#Denoted by NA and/or NaN for undefined mathematical operations.
#NA values have a class. So you can have both an integer NA and a missing character NA.

#is.na()
#is.nan()

x <- c(1,2, NA, 4, 5)
is.na(x)             #returns logical. shows third
is.nan(x)            # none are NaN.

x <- c(1,2, NA, NaN, 4, 5)
is.na(x)             #shows 2 TRUE. 
is.nan(x)            #shows 1 TRUE

#Missing values are very important in R, but can be very frustrating for new users.

###########################################
#HELPER FUNCTIONS
###########################################

#Compactly display the internal structure of an R object. Perhaps the most uesful diagnostic function in R.
str() 

#Names of elements within an object
names() 

#Retrieves the internal class of an object
class() 

#Get or set the type or storage mode of an object.
mode() 

#Retrieve or set the dimension of an object.
length()

#Retrieve or set the dimension of an object.
dim() 

#str is short for structure. You can use it on any object. Try the following:

x <- c(1,2,3,4,5,6,7,8,9,10)
y <- 1:10


class(x)
mode(x)
str(x)

###########################################
#CONDITIONAL EXECUTIONS
###########################################

##Comparison operators:
#Equal: ==
#Not equal: !=
#Greater than: > 
#Less than: <
#Greater than or equal: >= 
#Less than or equal: <=

##Logical operators:
#And: &
#Or: |
#Not: !

#When object is number, use number alone, when object is character (letters), must use ""

##If statements: if(condition = true) {return value 1} else {return value 2}
a <- 1
b <- 5
if(a==0){print(1)} else {print(2)}
if(a!=0){print(1)} else {print(2)}
if(a>=0){print(1)} else {print(2)}
if(a==0 & b==5){print(1)} else {print(2)}
if(a==0 | b==5){print(1)} else {print(2)}

#IfElse statements: ifelse(condition, condition=true, condition=false)
ifelse(a>=0, "yay", "boo")
ifelse(a<=0 & b!=4, "yay", "boo")
ifelse(a<=0 | b!=4, "yay", "boo")


survey <- read.csv("surveys.csv", header = TRUE)
class(survey$sex)
survey$sex <- ifelse(survey$sex == "M", "Male", "Female")

survey$taxa <- ifelse(survey$species_id == "RM" | survey$species_id == "PP",
                      "mammal", "bird")

survey$species_id <- as.character(survey$species_id)

survey$species_id <- ifelse(survey$species_id == "pp", "PP", survey$species_id)

survey$species_id <- as.factor(survey$species_id)
class(survey$species_id)

levels(survey$species_id)

survey$size <- ifelse(survey$weight > 250 & survey$hindfoot_length >= 50,
                      "large", "small")

##########################################
#SUBSETTING DATA
##########################################

data <- read.table("bird_data.txt", header = TRUE)

#Accessing column 1 of data
#subscript: [Row, Column] USE BRACKETS
SurveyID<-data[,1]
SurveyID

Elev <- data[,7]
Elev <- data$Elevation

#Accessing row 1 of data
data[1,]
data[1,1]
data[5,7]

#Accessing a subset of data: observations of density > 0
#Grabs subset of data with nonzero values
data1 <- data[data$Presence>0,]
data[data$Presence == 1, ]

Presence <- data$Presence[data$Water == 1]

#Accessing a subset of data: a portion of one variable based on another
#Grabs all data with elevation > 1.001m
data$Presence[data$Elevation>1.001]
data$Presence[!data$Elevation<1.001]

#Grabs all data points with elevation > 1.001m and presence of water
data$Presence[data$Elevation>1.001 & data$Water==1]


Florida <- data[data$State == "Florida",]

#OR use "subset" function
#subset(data, condition, select=data you want to select)
Elev1 <- subset(data, data$Elevation>1.001)
Elev2 <- data[data$Elevation > 1.001,]


Pt1 <- subset(data, data$Elevation>1.001, select=PointID)
Pt2 <- data$PointID[data$Elevation>1.001]


data3 <- subset(data, data$Elevation>1.001, select=c(SurveyID,PointID))

Georgia <- subset(data, data$State == "Georgia")

mean(Florida$Elevation)
mean(data$Elevation[data$State == "Florida"], na.rm = TRUE)


data <- read.table("bird_data.txt", header = TRUE)


tapply(X=data$Elevation, INDEX = data$State, FUN = mean, na.rm = TRUE)

data$habitat_type <- ifelse(data$Water == 1 & data$Elevation < 1,
                            "good", "bad")
class(data$habitat_type)

data$habitat_type <- as.factor(data$habitat_type)

levels(data$habitat_type)

Florida <- data[data$State == "Florida" & data$Water == 1,]
Florida <- subset(data, subset = data$State == "Florida" & data$Water ==1)

summary(Florida)

###########################################
#LOOPS
###########################################

##FOR loops
#for(variable in sequence){statements}

#for(random variable "in" start:end){statements}
#for(i in 1:length(data$SurveyID)){statements}
#for(i in 1:dim(data)[1]){statements}

#set dummy variable
c <- 0
for(i in 1:30){
  x <- c + i
  # print(x)
}

#Change sex from Male and Female to M and F

dim(data)

for(i in 1:400){
  data$Sex.2[i] <- ifelse(data$Sex[i] == "Male", 0, 1) #Make a new column with binary inputs
  print(i)
}


for(i in 1:dim(data)[1]){
  data$Sex.2[i] <- ifelse(data$Sex[i] == "Male", 0, 1) #Make a new column with binary inputs
}


survey <- read.csv("surveys.csv", header = TRUE)
survey_1977 <- survey[survey$year == 1977,]
survey_1977 <- subset(survey, subset = survey$year == 1977)

dim(survey_1977)
is.na(survey_1977$weight)

for(a in 1:dim(survey_1977)[1]){
  survey_1977$weight[a] <- ifelse(is.na(survey_1977$weight[a])==TRUE,
                                  0, survey_1977$weight[a])
  print(a)
}

#Replace species names
survey_1977$species_id <- as.character(survey_1977$species_id)
class(survey_1977$species_id)
  
for(a in 1:dim(survey_1977)[1]){
  survey_1977$species_id[a] <- ifelse(survey_1977$species_id[a] == "RM",  
                                      "RL", survey_1977$species_id[a])
  print(a)
  
}

class(survey_1977$species_id)

#New exercise
survey_hf <- survey[is.na(survey$hindfoot_length)==FALSE,]

for(s in 1:dim(survey_hf)[1]){
  if(survey_hf$year[s] >= 1977 & survey_hf$year[s] <= 1979){
    survey_hf$hindfoot_length[s] <- survey_hf$hindfoot_length[s] + 1} 
  else if(survey_hf$year[s] >= 1980 & survey_hf$year[s] <= 1989){
    survey_hf$hindfoot_length[s] <- survey_hf$hindfoot_length[s] - 2}
  else if(survey_hf$year[s] >= 1990 & survey_hf$year[s] <= 1999){
    survey_hf$hindfoot_length[s] <- survey_hf$hindfoot_length[s] - 1}
  else {survey_hf$hindfoot_length[s] <- survey_hf$hindfoot_length[s] + 2}
}


#Add temp
for(t in 1:dim(survey_hf)[1]){
  if(survey_hf$month[t] <= 2 | survey_hf$month[t] >= 12){
    survey_hf$temp[t] <- 21.1}
  else if(survey_hf$month[t] >= 3 & survey_hf$month[t] <= 5){
    survey_hf$temp[t] <- 25.6}
  else if(survey_hf$month[t] >= 6 & survey_hf$month[t] <= 8){
    survey_hf$temp[t] <- 22.3}
  else {survey_hf$temp[t] <- 21.5}
}

##WHILE loops
#while (condition) {statements}
z <- 0
while(z < 5) { 
  z <- z + 2
  print(z)  
}


###########################################
#CREATING YOUR OWN FUNCTIONS
###########################################

#my.function.name <- function(var1, var2){function body: return()}

#example: calculate mean
z<- c(1:50)
sum(z)/length(z)

arith.mean<-function(x){sum(x)/length(x)}
arith.mean(z)

y <- c(4:27)
arith.mean(y)

ex.funct <- function(x, y){
  z1 <- x/y
  z2 <- y^3
  z  = c(z1, z2)
  return(z)
}

#Returns the function itself
ex.funct

#Apply function
ex.funct(x=2, y=5)
ex.funct(2, 5)
ex.funct(y=5, x=2)
ex.funct(5,2)


#Example applying function within a FOR loop
ex.funct2 <- function(x){
  y <- x^2
  return(y) 
}
a <- 1
for(i in 1:10){
  b <- a + i
  output <- ex.funct2(b)
  print(output)
}

#STOP and WARNING
myfct <- function(x1) {
  if (x1>=0) print(x1) else stop("This function did not finish, because x1 < 0")
  warning("Value needs to be > 0")
}
myfct(x1=2)
myfct(x1=-2)


#########################
survey <- read.csv("surveys.csv", header = TRUE)

sub.yr <- function(x, years){
  sub <- subset(x, subset = x$year == year)
  return(sub)
}

survey_1977 <- sub.yr(x = survey, year = 1977)
survey_1999 <- sub.yr(x = survey, year = 1999)

FtoC <- function(temp){
  C <- (temp - 32)*(5/9)
  return(C)
}
FtoC(15)
FtoC(80)
