######################################################################################
########################  CHECK NORMALITY     ########################################
######################################################################################

#Read in survey data
data("iris")

#Plot histogram of sepal length
hist(iris$Sepal.Length)

#Plot histogram of sepal width
hist(iris$Sepal.Width)
hist(iris$Petal.Length)

#Plot Q-Q plot 
qqnorm(iris$Sepal.Length)
qqnorm(iris$Sepal.Width)
qqnorm(iris$Petal.Length)

#test normality
shapiro.test(iris$Sepal.Length)
shapiro.test(iris$Sepal.Width)
shapiro.test(iris$Petal.Length)

#Create correlation matrix
cor(iris)
cor(iris[,1:4])
corr.plot(iris[,1:4])


######################################################################################
########################  CHI-SQUARED FAMILY  ########################################
######################################################################################

#Remember that statistical tests from the chi-squared family are ALWAYS applied to CATEGORICAL DATA

#First you have to install a package called ‘MASS’ to run the test
#You can do this by either typing the code below into the r code lines
#OR you can click on the library drop down menu on the top and find ‘MASS’
install.packages(MASS)
library(MASS)

#If you have already downloaded this package previously, you can just check the box
#Find the list of packages that you have already downloaded in the right bottom window
#And click on the 'Packages' tab

#Now bring the data set 
pref <- read.table("chi.sq_data.txt", header = TRUE)
row.names(pref) <- c("Male", "Female")

#Click on the 'Insert Dataset' table, click on pref.txt, and import
#Attach the data so that you can search around to see what the data looks like
attach(pref)

#Now check out the full data set
pref

#Try searching just one of the colums to see what happens
coke

#Run the Chi-squared test
#Remember if your data is normally distributed you run a Chi-squared test for independance
chisq.test(pref)

#If you data is not normally distributed, you run a Fisher's exact test
#The Fisher's test is also commonly cited as the best test for dealing with small datasets
#Some researchers state for qualitative data, anything below an n=1000 should be considered small
fisher.test(pref)

#What do you think of the results?  What do they say about the data?

#Bird analysis
bird <- read.table("bird_data.txt", header = TRUE)
  
bird <- bird[bird$Presence == 1,]

df <- table(bird$Sex, bird$State)
chisq.test(df)

######################################################################################
###########################  T-TEST FAMILY  ##########################################
######################################################################################

#STUDENT'S T-TEST: an unpaired parametric t-test
#Bring in the unpaired_ttest file
height <-read.table("unpaired.ttest_data.txt", header = TRUE)
hist(height$height)
boxplot(height$height ~ height$group)

#Let's run a test for normality
shapiro.test(height$height)

#Now that we know that the data is normally distributed, let's test for equal variance
var.test(height ~ group, data = height)

#Now that we know that the datsets have equal variances, we can run a parametric t-test
t.test(height ~ group, data = height, var.equal = TRUE)
t.test(height ~ group, data = height, var.equal = TRUE, alternative = "two.sided")

#Are there differences present in height between groups? How does this compare to Excel?

#PAIRED T-TESTS: used when you take multiple measurements of the same group of organism
#Lets try a paired ttest using before and after data on the same group
#Bring in the paired_ttest dataset 
data <- read.table("paired.ttest_data.txt", header = TRUE)

#Let's make sure that we have the same number of before and after observations
xtabs(~Student + Time, data)

#First we need to structure the data set
Before = data$Score[data$Time=="Before"]
After  = data$Score[data$Time=="After"]
Difference = After - Before
x = Difference

#Now let's check and see if the data is normally distributed by graphing
hist(x, xlab="Difference (After - Before)")

#Try running a test for normality
shapiro.test(Before)
shapiro.test(After)

#Now run the paired t-test
t.test(Score ~ Time, data = data, paired = TRUE)

#Is there a significant difference?


#WILCOXON TEST: Now let’s try running a non-parametric t-test 
#First, simulate some data
women_weight <- c(38.9, 61.2, 73.3, 21.8, 63.4, 64.6, 48.4, 48.8, 48.5)
men_weight <- c(67.8, 60, 63.4, 76, 89.4, 73.3, 67.3, 61.3, 62.4) 
# Create a data frame
my_data <- data.frame( 
  group = rep(c("Female", "Male"), each = 9),
  weight = c(women_weight,  men_weight)
)

#Now let’s calculate some descriptive stats
summary(my_data$weight[my_data$group == "Male"])
sd(my_data$weight[my_data$group == "Male"])
var(my_data$weight[my_data$group == "Male"])

summary(my_data$weight[my_data$group == "Female"])
sd(my_data$weight[my_data$group == "Female"])
var(my_data$weight[my_data$group == "Female"])

#Now let’s visualize the data using a boxplot to see how it is distributed
boxplot(my_data$weight ~ my_data$group)

#Let's run a test for normality
shapiro.test(my_data$weight[my_data$group == "Male"])
shapiro.test(my_data$weight[my_data$group == "Female"])

#Plot the histograms
hist(my_data$weight[my_data$group == "Male"])
hist(my_data$weight[my_data$group == "Female"])

#We see that neither data set is normall distributed
#If you remember, having equal variance is a key test in a t-test
#So let’s run a variance test to see if the variances are equally distributed
var.test(my_data$weight ~ my_data$group)

#We can see that the variances are unequal
wilcox.test(my_data$weight ~ my_data$group, exact = FALSE)

#Read in data
bird <- read.table("bird_data.txt", header = TRUE)

FL <- bird[bird$State == "Florida",]
GA <- bird[bird$State == "Georgia",]

shapiro.test(FL$Elevation)
shapiro.test(GA$Elevation)
shapiro.test(bird$Elevation)

bird.sub <- bird[bird$State == "Florida" | bird$State == "Georgia",]

t.test(Elevation ~ State, data = bird.sub)

wilcox.test(Elevation ~ State, data = bird.sub)


#Bird data
bird <- read.table("bird_data.txt", header = TRUE)

bird.sub <- bird[bird$Sex == "Male" & bird$Presence == 1,]

shapiro.test(bird.sub$Elevation)

t.test(bird.sub$Elevation, alternative = "greater", mu = 1.0)




