###########################################
#BASIC PLOTTING
###########################################
?par #gives you help file of graphical parameters
window()
window=F ##For PC

quartz=T # For mac
quartz=F

#Read in bird datafile
data <- read.table("bird_data.txt", header = TRUE)


##SCATTERPLOT
plot(data$Easting, data$Northing)
plot(data$Easting, data$Northing, 
     xlab = "Easting (UTMs)", ylab = "Northing (UTMs)")

#Other alternative ways
plot(x = data$Easting, y = data$Northing)
plot(Northing ~ Easting, data = data)

#You can try different symbol shapes by varying the "pch" argument
plot(data$Easting, data$Northing, 
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16)
plot(data$Easting, data$Northing, 
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 23)
?plot

#Change shape colors
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     col = "blue", pch = 16)

#Change shape colors by presence/absence 
data$Color[data$Presence==0] = "blue" 
data$Color[data$Presence==1] = "red" 
head(data)
plot(data$Easting, data$Northing, 
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, col = data$Color)

#Add a legend
legend("topright", 
       c("Absence", "Presence"), 
       pch = c(16,16), 
       col = c("blue", "red")) 

?legend


# This tells R to put the legend in the top right of the graph, 
# then in the legend make labels for Absence/Presence,
# make the symbols and colours next to these labels 
# the same as what we specified for the graph 

#Add a legend wherever you click on the figure (the number within the "locator()" command signifies the number of click)
legend(locator(1), c("Absence", "Presence"), pch = c(16,16), col = c("blue", "red")) 

#Change size of symbols
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, cex = 2)
#http://www.phaget4.org/R/Rplotsymbols.png

#Change labels size, note that instead of "cex" we are using "cex.lab"
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, cex.lab = 1.2)

#Change size of axes values.
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, cex.axis= 1.2, 
     cex = 2, cex.lab = 1.2)

#Change color of axes labels
colors() #gives you list of possible colors
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, col.lab = "red")

#Change length of ticks
plot(data$Easting, data$Northing,
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16) #default is -0.05.  Sign means "inside"(+) or "outside"(-)

#Font type (regular=1, bold=2, itallic = 3, bold/itallic=4)
plot(data$Easting, data$Northing, 
     xlab = "Easting (UTMs)", 
     ylab = "Northing (UTMs)", 
     pch = 16, font.lab = 4)

#Remove axes and add box (good when creating maps)
plot(data$Easting, data$Northing, 
     xlab = "", 
     ylab = "", 
     pch = 16, 
     col = data$Color)
box()
axis(1)
axis(2)
axis(3)

#Save figure as pdf
pdf("Figure1a.pdf")
plot(data$Easting, data$Northing, xlab = "Easting (UTMs)", ylab = "Northing (UTMs)", pch =16, col = data$Color)
dev.off()
#can save same way as jpeg, sub .jpeg for .pdf

#Plot elevation against easting
plot(data$Easting, data$Elevation)

#Now add a fitted line
abline(lm(data$Elevation ~ data$Easting))
text(locator(1), "R2 = 0.8")


##HISTOGRAMS
hist(data$Elevation, 
     xlab = "Elevation (m)", main = "")

#Color can be changed
hist(data$Elevation, 
     xlab = "Elevation (m)", 
     main = "", col = "lightgreen")

#The number of bins can be also changed
hist(data$Elevation, 
     xlab = "Elevation (m)", 
     main = "")

#Now add a fitted curve
hist(data$Elevation, 
     xlab = "Elevation (m)", 
     main = "", prob = TRUE)
lines(density(data$Elevation), 
      col = "blue", lwd = 2)


##KERNEL DENSITY PLOTS
plot(density(data$Elevation))

#Filled density
plot(density(data$Elevation), 
     main = "Elevation (km)")
polygon(density(data$Elevation), 
        col = "red", border = "blue")

#Use density plots to compare groups
install.packages("sm")
library(sm)

#Read in dataset on MPG data of different cars
data("mtcars")
attach(mtcars)

#Create value labels 
cyl.f <- factor(cyl, levels = c(4,6,8), labels = c("4 cylinder", "6 cylinder", "8 cylinder")) 

#Plot densities 
sm.density.compare(mpg, cyl, xlab="Miles Per Gallon")
title(main="MPG Distribution by Car Cylinders")

#Add legend via mouse click
colfill<-c(2:(2+length(levels(cyl.f)))) 
legend(locator(1), levels(cyl.f), fill=colfill)


##DOT PLOTS
#Simple dot plots
dotchart(mtcars$mpg,labels = row.names(mtcars), cex = 0.7,
         main = "Gas Milage for Car Models", 
         xlab = "Miles Per Gallon")

#Sort by mpg, group and color by cylinder 
x <- mtcars[order(mtcars$mpg),]   # sort by mpg
x$cyl <- factor(x$cyl)            # it must be a factor
x$color[x$cyl==4] <- "red"
x$color[x$cyl==6] <- "blue"
x$color[x$cyl==8] <- "darkgreen"	
dotchart(x$mpg, labels = row.names(x), cex = 0.7, groups = x$cyl,
         main = "Gas Milage for Car Models\ngrouped by cylinder",
         xlab = "Miles Per Gallon", gcolor = "black", color = x$color)


##BOXPLOTS
#Create 2 different objects
pres<- data$Elevation[data$Presence == 1]
abs <- data$Elevation[data$Presence == 0]

#Display both graphs in the same figure
graph <- boxplot(pres,abs, xlab = "Unicorns", ylab = "Elevation")
graph < -boxplot(pres,abs, xlab = "Unicorns", ylab = "Elevation", ylim = c(0,5))
axis(1, at=1:2, labels=c("Presence", "Absence"))

#Adding color from 2:4 because 1 is black
boxplot(data$Elevation, col = 2)

#Remove outliers
boxplot(data$Elevation, col = 2, outline = FALSE)

#Add labels
boxplot(data$Elevation, col = 2, outline = FALSE, ylab = "Elevation", xlab = "Data Example")
axis(1, at = 1, labels = "example2")


##LINE PLOTS
x <- c(1:5); y <- x       # create some data
par(pch=22, col="blue")   # plotting symbol and color 
par(mfrow=c(2,4))         # all plots on one page 
opts = c("p","l","o","b","c","s","S","h") 
for(i in 1:length(opts)){ 
  heading = paste("type=",opts[i]) 
  plot(x, y, main=heading) 
  lines(x, y, type=opts[i]) 
}
dev.off()

#Try another chart with orange data
#Convert factor to numeric for convenience 
Orange$Tree <- as.numeric(Orange$Tree) 
ntrees <- max(Orange$Tree)

#Get the range for the x and y axis 
xrange <- range(Orange$age) 
yrange <- range(Orange$circumference) 

#Set up the plot 
plot(xrange, yrange, type = "n", 
     xlab = "Age (days)", ylab ="Circumference (mm)" ) 
colors <- rainbow(ntrees) 
linetype <- c(1:ntrees) 
plotchar <- seq(18, 18+ntrees, 1)

#Add lines with a for loop
for (i in 1:ntrees){ 
  tree <- subset(Orange, Tree == i) 
  lines(tree$age, tree$circumference, type="b", lwd = 1.5,
        lty = linetype[i], col = colors[i], pch = plotchar[i]) 
} 

#Add a title and subtitle 
title("Tree Growth", "example of line plot")

#Add a legend 
legend(xrange[1], yrange[2], 1:ntrees, cex = 0.8, col = colors,
       pch = plotchar, lty = linetype, title = "Tree")


##PIE CHARTS
#Simple Pie Chart
slices <- c(10, 12,4, 16, 8)
lbls <- c("US", "UK", "Australia", "Germany", "France")
pie(slices, labels = lbls, main = "Pie Chart of Countries")

#Pie Chart with Percentages
slices <- c(10, 12, 4, 16, 8) 
lbls <- c("US", "UK", "Australia", "Germany", "France")
pct <- round(slices/sum(slices)*100)
lbls <- paste(lbls, pct) # add percents to labels 
lbls <- paste(lbls, "%", sep = "") # ad % to labels 
pie(slices, labels = lbls, col = rainbow(length(lbls)),
    main = "Pie Chart of Countries")

#Pie Chart from data frame with Appended Sample Sizes
mytable <- table(iris$Species)
lbls <- paste(names(mytable), "\n", mytable, sep = "")
pie(mytable, labels = lbls, 
    main = "Pie Chart of Species\n (with sample sizes)")


##MULTIPLE FIGURES
par(mfrow=c(2,1))#Note that the notation is row,column, so in this case is 2 rows, 1 column
boxplot(data$Elevation, col = 2, outline = FALSE, ylab = "Elevation", xlab = "Data Example")
hist(data$Elevation, xlab = "Elevation (m)", main = "")
#dev.off() #turn figures off




